django_admin_search_filter
==========================

.. image:: https://img.shields.io/pypi/v/django_admin_search_filter.svg
    :target: https://pypi.python.org/pypi/django_admin_search_filter
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal.png
   :target: https://travis-ci.org/kragniz/cookiecutter-pypackage-minimal
   :alt: Latest Travis CI build status

Allows to create admin list filter as a search box for free-input

Idea is taken from this Medium article: https://hakibenita.medium.com/how-to-add-a-text-filter-to-django-admin-5d1db93772d8


Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`django_admin_search_filter` was written by `Mikhail Koipish <mkoypish@gmail.com>`_.
